@@ -1295,6 +1295,117 @@ class MembersApi(object):
             _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
+    def read_o_auth_window_uri(self, member_guid, user_guid, **kwargs):  # noqa: E501
+        """Read OAuth Window URI  # noqa: E501
+
+        This endpoint will generate an `oauth_window_uri` for the specified `member`.  # noqa: E501
+        This method makes a synchronous HTTP request by default. To make an
+        asynchronous HTTP request, please pass async_req=True
+        >>> thread = api.read_o_auth_window_uri(member_guid, user_guid, async_req=True)
+        >>> result = thread.get()
+
+        :param async_req bool
+        :param str member_guid: The unique identifier for a `member`. (required)
+        :param str user_guid: The unique identifier for a `user`. (required)
+        :param str referral_source: Should be either BROWSER or APP depending on the implementation.
+        :param str ui_message_webview_url_scheme: A scheme for routing the user back to the application state they were previously in.
+        :return: MemberResponseBody
+                 If the method is called asynchronously,
+                 returns the request thread.
+        """
+        kwargs['_return_http_data_only'] = True
+        if kwargs.get('async_req'):
+            return self.read_o_auth_window_uri_with_http_info(member_guid, user_guid, **kwargs)  # noqa: E501
+        else:
+            (data) = self.read_o_auth_window_uri_with_http_info(member_guid, user_guid, **kwargs)  # noqa: E501
+            return data
+
+    def read_o_auth_window_uri_with_http_info(self, member_guid, user_guid, **kwargs):  # noqa: E501
+        """Read OAuth Window URI  # noqa: E501
+
+        This endpoint will generate an `oauth_window_uri` for the specified `member`.  # noqa: E501
+        This method makes a synchronous HTTP request by default. To make an
+        asynchronous HTTP request, please pass async_req=True
+        >>> thread = api.read_o_auth_window_uri_with_http_info(member_guid, user_guid, async_req=True)
+        >>> result = thread.get()
+
+        :param async_req bool
+        :param str member_guid: The unique identifier for a `member`. (required)
+        :param str user_guid: The unique identifier for a `user`. (required)
+        :param str referral_source: Should be either BROWSER or APP depending on the implementation.
+        :param str ui_message_webview_url_scheme: A scheme for routing the user back to the application state they were previously in.
+        :return: MemberResponseBody
+                 If the method is called asynchronously,
+                 returns the request thread.
+        """
+
+        all_params = ['member_guid', 'user_guid', 'referral_source', 'ui_message_webview_url_scheme']  # noqa: E501
+        all_params.append('async_req')
+        all_params.append('_return_http_data_only')
+        all_params.append('_preload_content')
+        all_params.append('_request_timeout')
+
+        params = locals()
+        for key, val in six.iteritems(params['kwargs']):
+            if key not in all_params:
+                raise TypeError(
+                    "Got an unexpected keyword argument '%s'"
+                    " to method read_o_auth_window_uri" % key
+                )
+            params[key] = val
+        del params['kwargs']
+        # verify the required parameter 'member_guid' is set
+        if ('member_guid' not in params or
+                params['member_guid'] is None):
+            raise ValueError("Missing the required parameter `member_guid` when calling `read_o_auth_window_uri`")  # noqa: E501
+        # verify the required parameter 'user_guid' is set
+        if ('user_guid' not in params or
+                params['user_guid'] is None):
+            raise ValueError("Missing the required parameter `user_guid` when calling `read_o_auth_window_uri`")  # noqa: E501
+
+        collection_formats = {}
+
+        path_params = {}
+        if 'member_guid' in params:
+            path_params['member_guid'] = params['member_guid']  # noqa: E501
+        if 'user_guid' in params:
+            path_params['user_guid'] = params['user_guid']  # noqa: E501
+
+        query_params = []
+        if 'referral_source' in params:
+            query_params.append(('referral_source', params['referral_source']))  # noqa: E501
+        if 'ui_message_webview_url_scheme' in params:
+            query_params.append(('ui_message_webview_url_scheme', params['ui_message_webview_url_scheme']))  # noqa: E501
+
+        header_params = {}
+
+        form_params = []
+        local_var_files = {}
+
+        body_params = None
+        # HTTP header `Accept`
+        header_params['Accept'] = self.api_client.select_header_accept(
+            ['application/vnd.mx.atrium.v1+json'])  # noqa: E501
+
+        # Authentication setting
+        auth_settings = ['apiKey', 'clientID']  # noqa: E501
+
+        return self.api_client.call_api(
+            '/users/{user_guid}/members/{member_guid}/oauth_window_uri', 'GET',
+            path_params,
+            query_params,
+            header_params,
+            body=body_params,
+            post_params=form_params,
+            files=local_var_files,
+            response_type='MemberResponseBody',  # noqa: E501
+            auth_settings=auth_settings,
+            async_req=params.get('async_req'),
+            _return_http_data_only=params.get('_return_http_data_only'),
+            _preload_content=params.get('_preload_content', True),
+            _request_timeout=params.get('_request_timeout'),
+            collection_formats=collection_formats)
+
     def resume_member(self, member_guid, user_guid, body, **kwargs):  # noqa: E501
         """Resume aggregation from MFA  # noqa: E501
 
